freeports_analysis documentation — freeports_analysis 0.0.1 documentation

# freeports_analysis documentation

Contents:

- Installation
  - Using `pip`
  - From source
- Quickstart guide
- Command reference
- Package reference
  - freeports_analysis
- How to contribute
  - Setting up the local repo
  - Contribute
  - Guidelines
  - Contribution to the website
  - Resources

This packages is intended for generate a csv file from different finance pdf reports

Note

This project is under active development.